==> kapla-2.0.1.tgz: package/lib/observers/TokenObserver.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

import { ElementObserver } from '../observers';
import { IndexedMultimap } from '../multimap';
export var TokenObserver =
/*#__PURE__*/
function () {
  function TokenObserver(element, attributeName, delegate) {
    _classCallCheck(this, TokenObserver);

    this.attributeName = attributeName;
    this.delegate = delegate;
    this.elementObserver = new ElementObserver(element, this);
    this.tokensByElement = new IndexedMultimap();
  }

  _createClass(TokenObserver, [{
    key: "start",
    value: function start() {
      this.elementObserver.start();
    }
  }, {
    key: "stop",
    value: function stop() {
      this.elementObserver.stop();
    }
  }, {
    key: "refresh",
    value: function refresh() {
      this.elementObserver.refresh();
    }
  }, {
    key: "getElementsMatchingToken",
    value: function getElementsMatchingToken(token) {
      return this.tokensByElement.getKeysForValue(token);
    } // Delegate

  }, {
    key: "matchElement",
    value: function matchElement(element) {
      return element.hasAttribute(this.attributeName);
    }
  }, {
    key: "matchElementsInTree",
    value: function matchElementsInTree() {
      var tree = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.element;
      var match = this.matchElement(tree) ? [tree] : [];
      var matches = Array.from(tree.querySelectorAll(this.selector));
      return match.concat(matches);
    }
  }, {
    key: "elementMatched",
    value: function elementMatched(element) {
      var newTokens = Array.from(this._readTokenSetForElement(element));

      for (var _i = 0; _i < newTokens.length; _i++) {
        var token = newTokens[_i];

        this._elementMatchedToken(element, token);
      }
    }
  }, {
    key: "elementUnmatched",
    value: function elementUnmatched(element) {
      var tokens = this._getTokensForElement(element);

      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = tokens[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var token = _step.value;

          this._elementUnmatchedToken(element, token);
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return != null) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }
    }
  }, {
    key: "elementAttributeChanged",
    value: function elementAttributeChanged(element) {
      var newTokenSet = this._readTokenSetForElement(element);

      var _arr = Array.from(newTokenSet);

      for (var _i2 = 0; _i2 < _arr.length; _i2++) {
        var token = _arr[_i2];
        this.elementMatched(element, token);
      }

      var _iteratorNormalCompletion2 = true;
      var _didIteratorError2 = false;
      var _iteratorError2 = undefined;

      try {
        for (var _iterator2 = this._getTokensForElement(element)[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
          var _token = _step2.value;

          if (!newTokenSet.has(_token)) {
            this.elementUnmatched(element, _token);
          }
        }
      } catch (err) {
        _didIteratorError2 = true;
        _iteratorError2 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion2 && _iterator2.return != null) {
            _iterator2.return();
          }
        } finally {
          if (_didIteratorError2) {
            throw _iteratorError2;
          }
        }
      }
    } // Private

  }, {
    key: "_elementMatchedToken",
    value: function _elementMatchedToken(element, token) {
      if (!this.tokensByElement.has(element, token)) {
        this.tokensByElement.add(element, token);

        if (this.delegate.elementMatchedToken) {
          this.delegate.elementMatchedToken(element, token, this.attributeName);
        }
      }
    }
  }, {
    key: "_elementUnmatchedToken",
    value: function _elementUnmatchedToken(element, token) {
      if (this.tokensByElement.has(element, token)) {
        this.tokensByElement.delete(element, token);

        if (this.delegate.elementUnmatchedToken) {
          this.delegate.elementUnmatchedToken(element, token, this.attributeName);
        }
      }
    }
  }, {
    key: "_getTokensForElement",
    value: function _getTokensForElement(element) {
      return this.tokensByElement.getValuesForKey(element);
    }
  }, {
    key: "_readTokenSetForElement",
    value: function _readTokenSetForElement(element) {
      var tokens = new Set();
      var value = element.getAttribute(this.attributeName) || '';
      var _iteratorNormalCompletion3 = true;
      var _didIteratorError3 = false;
      var _iteratorError3 = undefined;

      try {
        for (var _iterator3 = value.split(/\s+/)[Symbol.iterator](), _step3; !(_iteratorNormalCompletion3 = (_step3 = _iterator3.next()).done); _iteratorNormalCompletion3 = true) {
          var token = _step3.value;

          if (token.length) {
            tokens.add(token);
          }
        }
      } catch (err) {
        _didIteratorError3 = true;
        _iteratorError3 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion3 && _iterator3.return != null) {
            _iterator3.return();
          }
        } finally {
          if (_didIteratorError3) {
            throw _iteratorError3;
          }
        }
      }

      return tokens;
    }
  }, {
    key: "selector",
    get: function get() {
      return "[".concat(this.attributeName, "]");
    }
  }]);

  return TokenObserver;
}();

==> kapla-2.1.4.tgz: package/lib/observers/TokenObserver.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

import { ElementObserver } from '../observers';
import { IndexedMultimap } from '../multimap';
export var TokenObserver =
/*#__PURE__*/
function () {
  function TokenObserver(element, attributeName, delegate) {
    _classCallCheck(this, TokenObserver);

    this.attributeName = attributeName;
    this.delegate = delegate;
    this.elementObserver = new ElementObserver(element, this);
    this.tokensByElement = new IndexedMultimap();
  }

  _createClass(TokenObserver, [{
    key: "start",
    value: function start() {
      this.elementObserver.start();
    }
  }, {
    key: "stop",
    value: function stop() {
      this.elementObserver.stop();
    }
  }, {
    key: "refresh",
    value: function refresh() {
      this.elementObserver.refresh();
    }
  }, {
    key: "getElementsMatchingToken",
    value: function getElementsMatchingToken(token) {
      return this.tokensByElement.getKeysForValue(token);
    } // Delegate

  }, {
    key: "matchElement",
    value: function matchElement(element) {
      return element.hasAttribute(this.attributeName);
    }
  }, {
    key: "matchElementsInTree",
    value: function matchElementsInTree() {
      var tree = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.element;
      var match = this.matchElement(tree) ? [tree] : [];
      var matches = Array.from(tree.querySelectorAll(this.selector));
      return match.concat(matches);
    }
  }, {
    key: "elementMatched",
    value: function elementMatched(element) {
      var newTokens = Array.from(this._readTokenSetForElement(element));

      for (var _i = 0, _newTokens = newTokens; _i < _newTokens.length; _i++) {
        var token = _newTokens[_i];

        this._elementMatchedToken(element, token);
      }
    }
  }, {
    key: "elementUnmatched",
    value: function elementUnmatched(element) {
      var tokens = this._getTokensForElement(element);

      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = tokens[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var token = _step.value;

          this._elementUnmatchedToken(element, token);
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return != null) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }
    }
  }, {
    key: "elementAttributeChanged",
    value: function elementAttributeChanged(element) {
      var newTokenSet = this._readTokenSetForElement(element);

      for (var _i2 = 0, _Array$from = Array.from(newTokenSet); _i2 < _Array$from.length; _i2++) {
        var token = _Array$from[_i2];
        this.elementMatched(element, token);
      }

      var _iteratorNormalCompletion2 = true;
      var _didIteratorError2 = false;
      var _iteratorError2 = undefined;

      try {
        for (var _iterator2 = this._getTokensForElement(element)[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
          var _token = _step2.value;

          if (!newTokenSet.has(_token)) {
            this.elementUnmatched(element, _token);
          }
        }
      } catch (err) {
        _didIteratorError2 = true;
        _iteratorError2 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion2 && _iterator2.return != null) {
            _iterator2.return();
          }
        } finally {
          if (_didIteratorError2) {
            throw _iteratorError2;
          }
        }
      }
    } // Private

  }, {
    key: "_elementMatchedToken",
    value: function _elementMatchedToken(element, token) {
      if (!this.tokensByElement.has(element, token)) {
        this.tokensByElement.add(element, token);

        if (this.delegate.elementMatchedToken) {
          this.delegate.elementMatchedToken(element, token, this.attributeName);
        }
      }
    }
  }, {
    key: "_elementUnmatchedToken",
    value: function _elementUnmatchedToken(element, token) {
      if (this.tokensByElement.has(element, token)) {
        this.tokensByElement.delete(element, token);

        if (this.delegate.elementUnmatchedToken) {
          this.delegate.elementUnmatchedToken(element, token, this.attributeName);
        }
      }
    }
  }, {
    key: "_getTokensForElement",
    value: function _getTokensForElement(element) {
      return this.tokensByElement.getValuesForKey(element);
    }
  }, {
    key: "_readTokenSetForElement",
    value: function _readTokenSetForElement(element) {
      var tokens = new Set();
      var value = element.getAttribute(this.attributeName) || '';
      var _iteratorNormalCompletion3 = true;
      var _didIteratorError3 = false;
      var _iteratorError3 = undefined;

      try {
        for (var _iterator3 = value.split(/\s+/)[Symbol.iterator](), _step3; !(_iteratorNormalCompletion3 = (_step3 = _iterator3.next()).done); _iteratorNormalCompletion3 = true) {
          var token = _step3.value;

          if (token.length) {
            tokens.add(token);
          }
        }
      } catch (err) {
        _didIteratorError3 = true;
        _iteratorError3 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion3 && _iterator3.return != null) {
            _iterator3.return();
          }
        } finally {
          if (_didIteratorError3) {
            throw _iteratorError3;
          }
        }
      }

      return tokens;
    }
  }, {
    key: "selector",
    get: function get() {
      return "[".concat(this.attributeName, "]");
    }
  }]);

  return TokenObserver;
}();
